validate_interface_name

Function validate_interface_name 

pub fn validate_interface_name(name: &str) -> Result<()>
Validate network interface name to prevent command injection Interface names should only contain alphanumeric chars, hyphens, and underscores